Crate bonked3d

Crate bonked3d 

Re-exports

pub extern crate parry3d as parry;

Modules

object
Define the physics objects Simple physics engine for the game
world
Define the world Define a physics world containing fixed and kinematic bodies

Functions

make_shared
Create a shared reference with a read-write lock

Type Aliases

Mask
Shared
Shared reference with a read-write lock